@@ -11,6 +11,7 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
                     title="", complab="", outclab="",
                     label.e="Experimental", label.c="Control",
                     byvar, bylab, print.byvar=TRUE,
+                    print.CMH=FALSE,
                     warn=TRUE
                     ){
   
@@ -508,6 +509,8 @@ metabin <- function(event.e, n.e, event.c, n.c, studlab,
   }
   res$print.byvar <- print.byvar
   
+  res$print.CMH <- print.CMH
+  
   res$version <- packageDescription("meta")$Version
   
   class(res) <- c("metabin", "meta")
