@@ -7,6 +7,7 @@ summary.meta <- function(object,
                          level.comb=object$level.comb,
                          comb.fixed=object$comb.fixed,
                          comb.random=object$comb.random,
+                         print.CMH=object$print.CMH,
                          warn=TRUE,
                          ...){
   
@@ -38,6 +39,10 @@ summary.meta <- function(object,
   if (length(print.byvar)==0){
     print.byvar <- TRUE
   }
+  ##
+  if (length(print.CMH)==0){
+    print.CMH <- FALSE
+  }
   
   
   if (length(level)==0){
@@ -309,6 +314,8 @@ summary.meta <- function(object,
   ##
   res$print.byvar <- print.byvar
   
+  res$print.CMH <- print.CMH
+  
   res$version <- packageDescription("meta")$Version
   
   res
